天使爱美丽 (豆瓣)
Description: 天使爱美丽电影简介和剧情介绍,天使爱美丽影评、图片、预告片、影讯、论坛、在线购票
Keywords: 天使爱美丽,Le fabuleux destin d'Amélie Poulain,天使爱美丽影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.113豆瓣电影Top250

# 天使爱美丽 Le fabuleux destin d'Amélie Poulain (2001)

导演: 让-皮埃尔·热内
编剧: 纪尧姆·洛朗 / 让-皮埃尔·热内
主演: 奥黛丽·塔图 / 马修·卡索维茨 / 吕菲斯 / 洛莱拉·克拉沃塔 / 塞尔·梅林 / 贾梅尔·杜布兹 / 克洛蒂尔德·莫莱特 / 克莱尔·莫里耶 / 伊莎贝尔·南蒂 / 多米尼克·皮侬 / 阿尔蒂斯·德·彭居埃恩 / 友兰达·梦露 / 于尔班·康塞利埃 / 莫里斯·贝尼舒 / 米歇尔·罗班 / 安德烈·达芒 / 克洛德·佩隆 / 阿尔梅尔 / 迪基·奥尔加多 / 凯文·迪亚士 / 弗洛拉·吉耶 / 阿莫里·巴博尔 / 欧仁·贝蒂埃 / 让·达里 / 马克·阿米约
类型: 剧情 / 喜剧 / 爱情
制片国家/地区: 法国 / 德国
语言: 法语 / 俄语
上映日期: 2001-04-25(法国) / 2001-08-16(德国)
片长: 122分钟
又名: 艾蜜莉的异想世界(台) / 天使艾米莉 / 天使艾美丽 / 阿梅丽的奇妙命运 / 艾蜜丽 / Amelie
IMDb: tt0211915
豆瓣评分
引用
8.7
928405人评价
5星
50.2%
4星
36.8%
3星
11.6%
2星
1.1%
1星
0.3%
好于 98% 爱情片
好于 98% 喜剧片
想看 看过
评价:
推荐

## 天使爱美丽的剧情简介 · · · · · ·

艾米莉（奥黛丽·塔图 Audrey Tautou 饰）有着别人看来不幸的童年——父亲给她做健康检查时，发现她心跳过快，便断定她患上心脏病，从此艾米莉与学校绝缘。随后因为一桩意外，母亲在她眼前突然死去。这一切都毫不影响艾米莉对生活的豁达乐观。
1997年，戴安娜王妃的去世让她倍感人生的孤独脆弱，艾米莉从此开始了一系列助人计划，包括自闭忧郁的邻居老人，被老板刻薄的菜摊伙计、遗失了童年器物的旧房东、爱情失意的咖啡店同事。但她万万想不到，成人录象带商店店员尼诺（马修·卡索维 Mathieu Kassovitz 饰），竟成为她的棘手对象，艾米莉开始了令人哭笑不得的另类计划…… ©豆瓣

## 天使爱美丽的演职员 · · · · · · ( 全部 38 )

- 让-皮埃尔·热内 导演
- 奥黛丽·塔图 饰 艾米莉
- 马修·卡索维茨 饰 尼诺
- 吕菲斯 饰 艾米莉的父亲
- 洛莱拉·克拉沃塔 饰 艾米莉的母亲
- 塞尔·梅林 饰 Raymond Dufayel

## 天使爱美丽的视频和图片 ······ ( 预告片4 | 添加视频评论 | 图片1042 · 添加 )

## 天使爱美丽的获奖情况 · · · · · · ( 全部 )

- 第74届奥斯卡金像奖
- 最佳原创剧本(提名)
- 让-皮埃尔·热内 / 纪尧姆·洛朗

- 第74届奥斯卡金像奖
- 最佳外语片(提名)
- 让-皮埃尔·热内

- 第59届金球奖
- 电影类 最佳外语片(提名)

## 喜欢这部电影的人也喜欢 · · · · · ·

  罗马假日

  重庆森林

  爱在黎明破晓前

  花样年华

  两小无猜

  甜蜜蜜

  恋恋笔记本

  傲慢与偏见

  泰坦尼克号

  剪刀手爱德华

我要写短评

## 天使爱美丽的短评 · · · · · · ( 全部 189409 条 )

热门 / 最新 / 好友

### 5955 有用 大头绿豆 看过 2005-06-12 02:22:17

艾米丽扶着那个盲老头走过马路和天桥和无数商店，飞快地告诉他自己看到了什么，然后又像天使一样离开。

### 7418 有用 Zephyrance 看过 2006-07-29 12:20:38

左上唇，右脸颊，左眼，右后脖颈。

### 4845 有用 流浪忧伤 看过 2011-01-06 20:25:38

有没有人觉得和重庆深林里的王菲有点相似？

### 3733 有用 寂地 看过 2006-01-01 17:46:23

看了心情会很好

### 2775 有用 米姐起飞 看过 2008-02-06 20:18:45

全心全力关怀他人 总比自怨自艾来得好

> 更多短评 189409条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 天使爱美丽的影评 · · · · · · ( 全部 2938 条 )

热门 / 最新 / 好友
公子羽 2006-02-19 02:08:24

## 孩子

我可以在照片上，毫不犹豫地从那些热闹的人群中分辨出哪一张是最寂寞的脸。 那一定是一张最不起眼的脸。占据的面积最小，在阴影里躲藏的最深。不会被人在意，也不会被人轻易发现的一张脸。 我也可以在公车上为任何一个面对面相坐的人描摹他背后的故事。 他们大多一... (展开)
7246 441 431回应 收起
jing 2005-08-14 11:09:47

## 天使爱美丽，让我欢喜，让我忘忧

周六的早晨，我选择了看碟。《天使爱美丽》使我在激动和狂喜中度过了美丽的2小时。 奥黛丽•塔图的微笑俘虏了我，她的笑容如此明媚，如此纯净。当她的笑容嫣然绽放时，顿然让人做出尘之想，就连世界也为之失色。 当然，影片本身也给了我巨大的喜悦。因为它设置的谜局不仅挑... (展开)
2691 177 353回应 收起
不吭声 2009-05-20 08:54:27

## 而孤独也不得称霸

看到影片结尾处，爱美丽一开门，很多人会感叹一句：哦，法国人！但是，如果只凭借这一点点小浪漫，《天使爱美丽》是很难在浪漫横溢的诸多法国电影中脱颖而出，成为矫矫不群的另类经典的。其实这部电影的着力点并不在爱情，片中探讨的是一个比爱情更为重大的主题，那就是孤独，... (展开)
2539 59 124回应 收起
maria 2007-01-27 08:17:41

## 我们都爱Emilie

每次看Emilie时都幸福无比，身上每一个毛细孔都浸满了欢乐。因为它告诉人们什么是生活的乐趣。每个人因为你自己都可以生活在童话中。甚至可以记住每一个小小的细节。这电影大概自己会看一辈子吧。 因为我和Emilie一样很奇怪，很善良，很敏感…… 我们有Emilie没有的幸福，但也... (展开)
701 68 124回应 收起
私享史 2005-12-22 10:31:34

## 对于Amélie的重度研究

熬夜重温了Amélie，也算是进一步读懂了这部片子吧，初次看完后的一种爱不释手多少有些无缘无故。但这次不同，读出了好多东西。我觉得它实质上是在探讨人自身的隐私和嗜好能在多大程度融入到人与人之间的沟通和交流之中。或者说是，每个人可以保留一点自己的小情趣，但更大程度... (展开)
783 166 157回应 收起
bychance 2007-01-15 12:23:11

## 平淡中的幸福

干冷的天空尽是阴霾，自己躲在暖和的小屋看着电影，本已惬意的氛围在观赏完此片后更是无比舒适。 主人公艾米利有着漾着温暖的眸子，美丽而狡黠的笑容，而除此之外，这个和名字一样普通的女孩喜欢将手指深深地插入米袋里，用汤匙敲碎结成固体状的油层，在运河里打水漂—... (展开)
468 21 85回应 收起
迟chichi 2008-01-18 13:59:37

## Sunny day just for U

又看了一次[天使爱美丽]. 第三次看,依然好喜欢里面节奏很快却又非常细腻的旁白.好喜欢细节里都是浪漫的画面. 我想每个人都有自娱自乐的小情绪, 不管是喜欢在咖啡桌下捏泡泡约瑟, 还是紧张的时候喜欢把手指插在绿豆罐子里的爱美丽. 似乎大家都应该有属于自己的... (展开)
288 6 52回应 收起
指甲划过黑板 2007-08-29 23:09:43

## 有细节的人生是美妙的

岔开五指，插入装满谷物的米袋中，知道那是一种什么样感觉吗？你喜欢那种感觉吗？Amelie知道，Amelie喜欢。 《天使爱美丽》的开头总是看不够，只为那一个个细节。有细节的人生总也品不够，有细节的人生是美妙的。 “1973年9月3日下午6点28分32秒，一只蓝丽蝇每分钟翅膀拍动1467... (展开)
205 12 31回应 收起
浅草西Sophie 2009-05-29 17:30:46

## Amélie：一部温暖的电影

我喜欢电影的开场白： 1973年9月3日，下午6时28分32秒。 一只每分钟振翅可达14670次的苍蝇降落在巴黎蒙马特的圣文森路； 同时，附近的露天餐厅，两只酒杯在台布上随风起舞； 同时，巴黎祖丹路9号5楼，高拉参加完葬礼，把亡友名字从地址簿上擦除； 同时，一条属于Raphaeuml Poul... (展开)
210 6 21回应 收起

> 更多影评 2938篇

添加新讨论

## 讨论区 · · · · · ·

很喜欢这个古灵精怪的角色 | 来自白菜帮子 |  | 2022-11-03 15:18:39
请问在哪里可以看。 | 来自豆友QoIGJCOCVQ |  | 2022-11-02 10:15:18
有多少人被海报吓到的 | 来自再也不睡觉 | 148 回应 | 2022-10-26 21:45:38
这个还有其他的版本吗，为啥现在没有我以前看过的... | 来自大梁客 |  | 2022-10-24 22:14:32
剪影 | 来自Trtw.Padf | 1 回应 | 2022-10-20 14:19:24

> 去这部影片的讨论区（全部581条）

## 关于《天使爱美丽》的问题 · · · · · · ( 全部46个 )

- 关于男主人公？ 10人回答
- 艾米丽为什么会喜欢上连诺啊？ 19人回答

> 全部46个问题

## 在哪儿看这部电影 · · · · · ·

- 优酷视频 VIP免费观看
- 腾讯视频 VIP免费观看

## 本片原声正在播放 · · · · · ·

去豆瓣音乐收听

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 【豆瓣五星电影集中营】(1/3) (影志)
- 【浪漫爱情轻喜】 (影志)
- 电影学院本科生必看100部 (志国)
- 那些牛叉闪闪的片子 (家庭种菜笔记)

## 谁在看这部电影 · · · · · ·

- Victor
  1分钟前 想看
- 狗小叙倒
  4分钟前 想看
- momo
  5分钟前 看过

1663932人看过 / 365574人想看

订阅天使爱美丽的评论:
feed: rss 2.0